@@ -17,8 +17,6 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id$ */
-
 #ifndef ZEND_GENERATORS_H
 #define ZEND_GENERATORS_H
 
@@ -41,12 +39,12 @@ typedef struct _zend_generator zend_generator;
 struct _zend_generator_node {
 	zend_generator *parent; /* NULL for root */
 	uint32_t children;
-	union { /* HashTable / hard coded array for faster access */
-		HashTable ht; /* if > 4 children */
-		struct {
+	union {
+		HashTable *ht; /* if multiple children */
+		struct { /* if one child */
 			zend_generator *leaf;
 			zend_generator *child;
-		} array[4]; /* if <= 4 children */
+		} single;
 	} child;
 	union {
 		zend_generator *leaf; /* if > 0 children */
